@@ -5,14 +5,12 @@ class Action(object):
     def __init__(self, name, keys=None, variables=None):
         self.name = name
         self.keys = keys or dict()
-        if not isinstance(variables, Iterable):
-            variables = dict()
         self.variables = variables or dict()
 
     def __str__(self):
         package = "Action: %s\r\n" % self.name
         for key in self.keys:
-            if key != "Action" and key != "Variables":
+            if key != "Action" and key != "Variables" and key != "auxiliar_commands":
                 package += "%s: %s\r\n" % (key, self.keys[key])
         for var in self.variables:
             package += "Variable: %s=%s\r\n" % (var, self.variables[var])
