@@ -1,13 +1,9 @@
-from typing import Dict
-from dataclasses import dataclass
+import attr
 from AsteriskCommandApi.commons.asterisk_command import AsteriskCommand
 
 
-@dataclass
+@attr.s(auto_attribs=True)
 class GetInfoAnexos(AsteriskCommand):
     ActionID: str
     Action: str = "GetInfoAnexos"
     is_asterisk_command: bool = False
-
-    def as_dict(self) -> Dict:
-        return {"Action": self.Action, "ActionID": self.ActionID}
