@@ -10,22 +10,17 @@ class TestCommands(TestCase):
         action_id = str(uuid4())
 
         command = Atxfer(
-            ActionID=action_id,
-            Channel="SIP/123",
-            Context="Test",
-            Exten="SIP/111",
-            Priority="1",
-            peerName="1000",
+            ActionID=action_id, Channel="SIP/123", Context="Test", Exten="SIP/111", Priority="1", peerName="1000",
         )
 
         expected_dictionary = {
-            "Action": "Atxfer",
             "ActionID": action_id,
             "Channel": "SIP/123",
             "Context": "Test",
             "Exten": "SIP/111",
             "Priority": "1",
             "peerName": "1000",
+            "Action": "Atxfer",
         }
 
         expected_asterisk_command = Auxiliar.format_as_asterisk_command(
@@ -44,7 +39,4 @@ class TestCommands(TestCase):
         self.assertDictEqual(command.as_dict(), expected_dictionary)
         self.assertTrue(command.is_asterisk_command)
         self.assertEqual(str(command.as_asterisk_command()), expected_asterisk_command)
-
-        self.assertEqual(
-            command.as_json_asterisk_command(), json.dumps(expected_dictionary)
-        )
+        self.assertEqual(command.as_json_asterisk_command(), json.dumps(expected_dictionary))
