@@ -1,6 +1,6 @@
 from unittest import TestCase
 from uuid import uuid4
-from AsteriskCommand.core_show_channels import CoreShowChannels
+from AsteriskCommandApi.core_show_channels import CoreShowChannels
 from tests.commands.auxiliar_commands import Auxiliar
 
 
