@@ -26,7 +26,7 @@ class TestCommands(TestCase):
         }
 
         expected_dictionary = {
-            "Action": "Originate",
+            "Variables": {"IDRegistro": "100", "CallActionID": transaction_id, "AgentCode": "999",},
             "ActionID": action_id,
             "Channel": "SIP/100",
             "Context": "Test",
@@ -34,11 +34,7 @@ class TestCommands(TestCase):
             "Priority": "1",
             "Callerid": "10000",
             "Timeout": 30,
-            "Variables": {
-                "IDRegistro": "100",
-                "CallActionID": transaction_id,
-                "AgentCode": "999",
-            },
+            "Action": "Originate",
         }
 
         expected_asterisk_command = Auxiliar.format_as_asterisk_command(
@@ -60,7 +56,5 @@ class TestCommands(TestCase):
 
         self.assertTrue(command.is_asterisk_command)
         self.assertDictEqual(command.as_dict(), expected_dictionary)
-        self.assertEqual(
-            command.as_json_asterisk_command(), json.dumps(expected_dictionary)
-        )
+        self.assertEqual(command.as_json_asterisk_command(), json.dumps(expected_dictionary))
         self.assertEqual(str(command.as_asterisk_command()), expected_asterisk_command)
